/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED BY BPFTOOL! */
#ifndef __ARENA_HTAB_SKEL_H__
#define __ARENA_HTAB_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct arena_htab {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *arena;
		struct bpf_map *bss;
	} maps;
	struct {
		struct bpf_program *arena_htab_llvm;
	} progs;
	struct {
		struct bpf_link *arena_htab_llvm;
	} links;
	struct arena_htab__bss {
		bool skip;
		int zero;
		void *htab_for_user;
	} *bss;

#ifdef __cplusplus
	static inline struct arena_htab *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct arena_htab *open_and_load();
	static inline int load(struct arena_htab *skel);
	static inline int attach(struct arena_htab *skel);
	static inline void detach(struct arena_htab *skel);
	static inline void destroy(struct arena_htab *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
arena_htab__destroy(struct arena_htab *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
arena_htab__create_skeleton(struct arena_htab *obj);

static inline struct arena_htab *
arena_htab__open_opts(const struct bpf_object_open_opts *opts)
{
	struct arena_htab *obj;
	int err;

	obj = (struct arena_htab *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = arena_htab__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	arena_htab__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct arena_htab *
arena_htab__open(void)
{
	return arena_htab__open_opts(NULL);
}

static inline int
arena_htab__load(struct arena_htab *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct arena_htab *
arena_htab__open_and_load(void)
{
	struct arena_htab *obj;
	int err;

	obj = arena_htab__open();
	if (!obj)
		return NULL;
	err = arena_htab__load(obj);
	if (err) {
		arena_htab__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
arena_htab__attach(struct arena_htab *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
arena_htab__detach(struct arena_htab *obj)
{
	bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *arena_htab__elf_bytes(size_t *sz);

static inline int
arena_htab__create_skeleton(struct arena_htab *obj)
{
	struct bpf_object_skeleton *s;
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "arena_htab";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 2;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	s->maps[0].name = "arena";
	s->maps[0].map = &obj->maps.arena;

	s->maps[1].name = "arena_ht.bss";
	s->maps[1].map = &obj->maps.bss;
	s->maps[1].mmaped = (void **)&obj->bss;

	/* programs */
	s->prog_cnt = 1;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "arena_htab_llvm";
	s->progs[0].prog = &obj->progs.arena_htab_llvm;
	s->progs[0].link = &obj->links.arena_htab_llvm;

	s->data = arena_htab__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *arena_htab__elf_bytes(size_t *sz)
{
	static const char data[] __attribute__((__aligned__(8))) = "\
\x7f\x45\x4c\x46\x02\x02\x01\0\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x20\xa0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x0c\0\
\x01\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x2e\x74\x65\
\x78\x74\0\x73\x79\x73\x63\x61\x6c\x6c\0\x2e\x6d\x61\x70\x73\0\x2e\x62\x73\x73\
\0\x6c\x69\x63\x65\x6e\x73\x65\0\x61\x72\x65\x6e\x61\x5f\x68\x74\x61\x62\x2e\
\x63\0\x4c\x42\x42\x30\x5f\x38\0\x4c\x42\x42\x30\x5f\x32\0\x4c\x42\x42\x30\x5f\
\x35\0\x4c\x42\x42\x30\x5f\x34\0\x4c\x42\x42\x30\x5f\x37\0\x4c\x42\x42\x31\x5f\
\x38\0\x4c\x42\x42\x31\x5f\x32\0\x4c\x42\x42\x31\x5f\x35\0\x4c\x42\x42\x31\x5f\
\x34\0\x4c\x42\x42\x31\x5f\x37\0\x70\x61\x67\x65\x5f\x66\x72\x61\x67\x5f\x63\
\x75\x72\x5f\x6f\x66\x66\x73\x65\x74\0\x70\x61\x67\x65\x5f\x66\x72\x61\x67\x5f\
\x63\x75\x72\x5f\x70\x61\x67\x65\0\x4c\x42\x42\x31\x5f\x31\x31\0\x4c\x42\x42\
\x31\x5f\x39\0\x4c\x42\x42\x31\x5f\x32\x30\0\x4c\x42\x42\x31\x5f\x31\x33\0\x4c\
\x42\x42\x31\x5f\x31\x35\0\x4c\x42\x42\x31\x5f\x31\x38\0\x68\x74\x61\x62\x5f\
\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\0\x68\x74\x61\x62\x5f\x75\x70\x64\
\x61\x74\x65\x5f\x65\x6c\x65\x6d\0\x61\x72\x65\x6e\x61\0\x62\x70\x66\x5f\x61\
\x72\x65\x6e\x61\x5f\x61\x6c\x6c\x6f\x63\x5f\x70\x61\x67\x65\x73\0\x62\x70\x66\
\x5f\x61\x72\x65\x6e\x61\x5f\x66\x72\x65\x65\x5f\x70\x61\x67\x65\x73\0\x68\x74\
\x61\x62\x5f\x69\x6e\x69\x74\0\x61\x72\x65\x6e\x61\x5f\x68\x74\x61\x62\x5f\x6c\
\x6c\x76\x6d\0\x73\x6b\x69\x70\0\x7a\x65\x72\x6f\0\x5f\x6c\x69\x63\x65\x6e\x73\
\x65\0\x68\x74\x61\x62\x5f\x66\x6f\x72\x5f\x75\x73\x65\x72\0\x2e\x72\x65\x6c\
\x2e\x74\x65\x78\x74\0\x2e\x72\x65\x6c\x73\x79\x73\x63\x61\x6c\x6c\0\x2e\x42\
\x54\x46\0\x2e\x42\x54\x46\x2e\x65\x78\x74\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x32\x04\0\xff\xf1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x3f\0\0\0\x03\0\0\0\0\0\
\0\0\xe8\0\0\0\0\0\0\0\0\0\0\0\x46\0\0\0\x03\0\0\0\0\0\0\0\x90\0\0\0\0\0\0\0\0\
\0\0\0\x4d\0\0\0\x03\0\0\0\0\0\0\0\x78\0\0\0\0\0\0\0\0\0\0\0\x54\0\0\0\x03\0\0\
\0\0\0\0\0\xd0\0\0\0\0\0\0\0\0\0\0\0\x5b\0\0\0\x03\0\0\0\0\0\0\0\xe0\0\0\0\0\0\
\0\0\0\0\0\0\x62\0\0\0\x03\0\0\0\0\0\0\x01\xf0\0\0\0\0\0\0\0\0\0\0\0\x69\0\0\0\
\x03\0\0\0\0\0\0\x01\x90\0\0\0\0\0\0\0\0\0\0\0\x70\0\0\0\x03\0\0\0\0\0\0\x01\
\x78\0\0\0\0\0\0\0\0\0\0\0\x77\0\0\0\x03\0\0\0\0\0\0\x01\xd0\0\0\0\0\0\0\0\0\0\
\0\0\x7e\0\0\0\x03\0\0\0\0\0\0\x01\xe0\0\0\0\0\0\0\0\0\0\0\0\x85\x01\0\0\x06\0\
\0\0\0\0\0\x10\x10\0\0\0\0\0\0\x08\0\0\0\0\x9a\x01\0\0\x06\0\0\0\0\0\0\0\x10\0\
\0\0\0\0\0\x10\0\0\0\0\xad\0\0\0\x03\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\
\xb5\0\0\0\x03\0\0\0\0\0\0\x02\x68\0\0\0\0\0\0\0\0\0\0\0\xbc\0\0\0\x03\0\0\0\0\
\0\0\x04\xf0\0\0\0\0\0\0\0\0\0\0\0\xc4\0\0\0\x03\0\0\0\0\0\0\x03\x58\0\0\0\0\0\
\0\0\0\0\0\0\xcc\0\0\0\x03\0\0\0\0\0\0\x03\xf0\0\0\0\0\0\0\0\0\0\0\0\xd4\0\0\0\
\x03\0\0\0\0\0\0\x04\x80\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x04\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xdc\
\x22\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xf0\0\0\0\xed\x22\0\0\x03\0\0\0\0\0\
\0\0\xf0\0\0\0\0\0\0\x04\x10\0\0\0\xfe\x11\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x18\0\0\x01\x04\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x1a\x20\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x2f\x12\0\0\x03\0\0\0\0\0\0\x05\0\
\0\0\0\0\0\0\0\x70\0\0\x01\x39\x12\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\0\
\0\x01\x49\x11\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\x01\x4e\x11\0\0\
\x06\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x04\0\0\x01\x53\x11\0\0\x07\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x04\0\0\x01\x5c\x11\0\0\x06\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\
\x08\xbf\x11\0\x01\0\0\0\x01\x79\x31\0\0\0\0\0\0\xbf\x33\0\x01\0\0\0\x01\x61\
\x11\0\x08\0\0\0\0\x07\x10\0\0\xff\xff\xff\xff\x5f\x12\0\0\0\0\0\0\x67\x10\0\0\
\0\0\0\x20\x77\x10\0\0\0\0\0\x20\x67\x10\0\0\0\0\0\x03\x0f\x31\0\0\0\0\0\0\xb7\
\0\0\0\0\0\0\0\x79\x13\0\0\0\0\0\0\x15\x10\0\x10\0\0\0\0\xbf\x11\0\x01\0\0\0\
\x01\x05\0\0\x03\0\0\0\0\x15\x30\0\x0d\0\0\0\0\xbf\x33\0\x01\0\0\0\x01\xbf\x13\
\0\0\0\0\0\0\x79\x31\0\0\0\0\0\0\x61\x51\xff\xf0\0\0\0\0\xbf\x42\0\0\0\0\0\0\
\x67\x40\0\0\0\0\0\x20\x77\x40\0\0\0\0\0\x20\x5d\x54\0\x02\0\0\0\0\x61\x51\xff\
\xf4\0\0\0\0\x1d\x54\0\x02\0\0\0\0\xe5\0\0\0\0\x02\0\0\x05\0\xff\xf3\0\0\0\0\
\x61\x01\xff\xf8\0\0\0\0\x95\0\0\0\0\0\0\0\x7b\xa3\xff\xe8\0\0\0\0\xbf\x72\0\0\
\0\0\0\0\xbf\x11\0\x01\0\0\0\x01\x79\x81\0\0\0\0\0\0\xbf\x88\0\x01\0\0\0\x01\
\x61\x11\0\x08\0\0\0\0\x07\x10\0\0\xff\xff\xff\xff\x5f\x17\0\0\0\0\0\0\x67\x10\
\0\0\0\0\0\x20\x77\x10\0\0\0\0\0\x20\x67\x10\0\0\0\0\0\x03\x0f\x81\0\0\0\0\0\0\
\xb7\x50\0\0\0\0\0\0\x79\x18\0\0\0\0\0\0\x15\x10\0\x11\0\0\0\0\xbf\x11\0\x01\0\
\0\0\x01\x05\0\0\x03\0\0\0\0\x15\x20\0\x0e\0\0\0\0\xbf\x22\0\x01\0\0\0\x01\xbf\
\x12\0\0\0\0\0\0\x79\x21\0\0\0\0\0\0\x61\x41\xff\xf0\0\0\0\0\xbf\x37\0\0\0\0\0\
\0\x67\x30\0\0\0\0\0\x20\x77\x30\0\0\0\0\0\x20\x5d\x43\0\x02\0\0\0\0\x61\x41\
\xff\xf4\0\0\0\0\x1d\x43\0\x02\0\0\0\0\xe5\0\0\0\0\x03\0\0\x05\0\xff\xf3\0\0\0\
\0\x07\x10\0\0\xff\xff\xff\xf0\xbf\x51\0\0\0\0\0\0\x7b\xa5\xff\xf0\0\0\0\0\x85\
\0\0\0\0\0\0\x08\x67\0\0\0\0\0\0\x20\x77\0\0\0\0\0\0\x20\xbf\x10\0\0\0\0\0\0\
\x67\x10\0\0\0\0\0\x02\x18\x60\0\0\0\0\x10\x10\0\0\0\0\0\0\0\0\x0f\x61\0\0\0\0\
\0\0\x67\0\0\0\0\0\0\x03\x18\x90\0\0\0\0\0\x10\0\0\0\0\0\0\0\0\x0f\x90\0\0\0\0\
\0\0\x79\x09\0\0\0\0\0\0\x55\0\0\x13\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\xb7\x20\0\0\0\0\0\0\xb7\x30\0\0\0\0\0\x01\x18\x40\0\0\xff\xff\xff\xff\0\0\0\
\0\0\0\0\0\xb7\x50\0\0\0\0\0\0\x85\x01\0\0\xff\xff\xff\xff\x18\x50\0\0\xff\xff\
\xff\xf4\0\0\0\0\0\0\0\0\x79\x2a\xff\xf0\0\0\0\0\x15\0\0\x45\0\0\0\0\xbf\0\0\
\x01\0\0\0\x01\x7b\x90\0\0\0\0\0\0\xb7\x10\0\0\0\0\0\0\x7b\x01\x0f\xf8\0\0\0\0\
\xb7\x10\0\0\0\0\x0f\xd8\xb7\x30\0\0\0\0\0\x01\x05\0\0\x0b\0\0\0\0\xbf\0\0\x01\
\0\0\0\x01\x61\x16\0\0\0\0\0\0\x67\x10\0\0\0\0\0\x20\x18\x20\0\0\0\0\0\0\0\0\0\
\0\xff\xff\xff\xe0\x0f\x12\0\0\0\0\0\0\xc7\x10\0\0\0\0\0\x20\xc5\x10\xff\xe5\0\
\0\0\0\x79\x30\x0f\xf8\0\0\0\0\x07\x30\0\0\0\0\0\x01\x79\x2a\xff\xf0\0\0\0\0\
\x7b\x03\x0f\xf8\0\0\0\0\x63\x61\0\0\0\0\0\0\x67\x10\0\0\0\0\0\x20\x77\x10\0\0\
\0\0\0\x20\x0f\x01\0\0\0\0\0\0\x79\x1a\xff\xe8\0\0\0\0\x63\x01\0\x08\0\0\0\0\
\x63\x07\0\0\0\0\0\0\x63\x07\0\x04\0\0\0\0\x79\x18\0\0\0\0\0\0\xbf\x11\0\x01\0\
\x01\0\0\x07\0\0\0\0\0\0\x10\xbf\0\0\x01\0\0\0\x01\x7b\x01\0\0\0\0\0\0\xbf\x11\
\0\x01\0\0\0\x01\x15\x10\0\x03\0\0\0\0\xbf\x30\0\0\0\0\0\0\xbf\x33\0\x01\0\x01\
\0\0\x7b\x13\0\x08\0\0\0\0\xbf\0\0\x01\0\x01\0\0\x7b\x80\0\0\0\0\0\0\xbf\x88\0\
\x01\0\x01\0\0\xbf\0\0\x01\0\0\0\x01\x7b\x08\0\x08\0\0\0\0\xb7\x50\0\0\0\0\0\0\
\x15\x20\0\x19\0\0\0\0\x79\x12\0\x10\0\0\0\0\x79\x42\0\x18\0\0\0\0\xbf\x11\0\
\x01\0\x01\0\0\xbf\x44\0\x01\0\0\0\x01\x79\x34\0\0\0\0\0\0\xbf\x33\0\x01\0\0\0\
\x01\x7b\xa1\xff\xf8\0\0\0\0\x15\x10\0\x03\0\0\0\0\xbf\x44\0\x01\0\x01\0\0\xbf\
\x11\0\x01\0\0\0\x01\x7b\x14\0\x08\0\0\0\0\xb7\x10\0\0\0\0\x01\x22\x7b\x21\0\
\x18\0\0\0\0\xb7\x10\0\0\0\0\x01\0\x7b\x21\0\x10\0\0\0\0\x57\x20\0\0\xff\xff\
\xf0\0\x79\x12\x0f\xf8\0\0\0\0\x07\x10\0\0\xff\xff\xff\xff\x7b\x21\x0f\xf8\0\0\
\0\0\x55\x10\0\x05\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x30\0\0\0\0\
\0\x01\x85\x01\0\0\xff\xff\xff\xff\xb7\x50\0\0\0\0\0\0\xbf\x05\0\0\0\0\0\0\x95\
\0\0\0\0\0\0\0\xbf\x61\0\0\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x20\
\0\0\0\0\0\0\xb7\x30\0\0\0\0\0\x02\x18\x40\0\0\xff\xff\xff\xff\0\0\0\0\0\0\0\0\
\xb7\x50\0\0\0\0\0\0\x85\x01\0\0\xff\xff\xff\xff\xbf\0\0\x01\0\x01\0\0\xb7\x10\
\0\0\0\0\x04\0\x63\x61\0\x08\0\0\0\0\x7b\x60\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x18\
\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x20\0\0\0\0\0\x01\x73\x12\0\0\0\0\0\0\xb7\
\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x47\x50\x4c\0\0\0\0\0\0\0\0\0\0\0\x02\x20\0\0\0\x16\0\0\0\x01\0\0\0\0\0\0\
\x02\x40\0\0\0\x16\0\0\0\x01\0\0\0\0\0\0\x02\x68\0\0\0\x19\0\0\0\x01\0\0\0\0\0\
\0\x02\xa0\0\0\0\x1a\0\0\0\x0a\0\0\0\0\0\0\x04\xc8\0\0\0\x19\0\0\0\x01\0\0\0\0\
\0\0\x04\xe0\0\0\0\x1b\0\0\0\x0a\0\0\0\0\0\0\x05\x08\0\0\0\x19\0\0\0\x01\0\0\0\
\0\0\0\x05\x40\0\0\0\x1a\0\0\0\x0a\0\0\0\0\0\0\0\0\0\0\0\x1e\0\0\0\x01\xeb\x9f\
\x01\0\0\0\0\x18\0\0\0\0\0\0\x04\x08\0\0\x04\x08\0\0\x0a\x81\0\0\0\0\x02\0\0\0\
\0\0\0\x03\0\0\0\x01\x01\0\0\0\0\0\0\x04\x01\0\0\x20\0\0\0\0\x03\0\0\0\0\0\0\0\
\0\0\0\x02\0\0\0\x04\0\0\0\x21\0\0\0\x05\x01\0\0\0\0\0\0\x04\0\0\0\x20\0\0\0\0\
\x02\0\0\0\0\0\0\x06\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\x04\0\0\
\0\0\0\x02\0\0\0\0\0\0\x08\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\
\x64\0\0\0\0\x04\0\0\x03\0\0\0\x18\0\0\0\x19\0\0\0\x01\0\0\0\0\0\0\0\x1e\0\0\0\
\x05\0\0\0\x40\0\0\0\x28\0\0\0\x07\0\0\0\x80\0\0\0\x34\x0e\0\0\0\0\0\0\x09\0\0\
\0\x01\0\0\0\0\x02\0\0\0\0\0\0\x0c\0\0\0\x3a\x08\0\0\0\0\0\0\x0d\0\0\0\x41\x04\
\0\0\x02\0\0\0\x10\0\0\0\x46\0\0\0\x0e\0\0\0\0\0\0\0\x4e\0\0\0\x02\0\0\0\x40\0\
\0\0\0\x02\0\0\0\0\0\0\x0f\0\0\0\x58\x08\0\0\0\0\0\0\x2f\0\0\0\0\x0d\0\0\x02\0\
\0\0\x02\0\0\0\x41\0\0\0\x0b\0\0\0\x66\0\0\0\x02\0\0\0\x6a\x0c\0\0\x01\0\0\0\
\x10\0\0\0\x7b\x11\0\0\0\0\0\0\x11\0\0\0\0\0\0\0\0\x0d\0\0\x03\0\0\0\x02\0\0\0\
\x41\0\0\0\x0b\0\0\0\x66\0\0\0\x02\0\0\0\x85\0\0\0\x02\0\0\0\x8b\x0c\0\0\x01\0\
\0\0\x13\0\0\0\x7b\x11\0\0\0\0\0\0\x14\0\0\0\0\0\0\0\0\x0d\0\0\x05\0\0\0\x17\0\
\0\0\0\0\0\0\x17\0\0\0\0\0\0\0\x17\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x02\0\0\0\0\
\0\0\0\x1a\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\x9c\x08\0\0\0\0\0\0\x19\0\0\0\xa2\
\x01\0\0\0\0\0\0\x04\0\0\0\x20\0\0\0\xaf\x08\0\0\0\0\0\0\x1b\0\0\0\xb5\x01\0\0\
\0\0\0\0\x08\0\0\0\x40\0\0\0\xc8\x0c\0\0\x02\0\0\0\x16\0\0\0\0\x0d\0\0\x03\0\0\
\0\0\0\0\0\0\0\0\0\x17\0\0\0\0\0\0\0\x17\0\0\0\0\0\0\0\x18\0\0\0\xde\x0c\0\0\
\x02\0\0\0\x1d\0\0\0\0\x0d\0\0\x01\0\0\0\0\0\0\0\x41\0\0\0\x0b\0\0\0\xf3\x0c\0\
\0\x01\0\0\0\x1f\0\0\0\0\x0d\0\0\x01\0\0\0\x02\0\0\0\xfd\0\0\0\x17\0\0\x01\x01\
\x0c\0\0\x01\0\0\0\x21\0\0\x01\x11\x08\0\0\0\0\0\0\x24\0\0\x01\x16\x01\0\0\0\0\
\0\0\x01\x04\0\0\x08\0\0\x01\x1c\x0e\0\0\0\0\0\0\x23\0\0\0\x01\0\0\x01\x21\x0e\
\0\0\0\0\0\0\x02\0\0\0\x01\0\0\x01\x26\x01\0\0\0\0\0\0\x01\x01\0\0\x08\0\0\0\0\
\x03\0\0\0\0\0\0\0\0\0\0\x27\0\0\0\x04\0\0\0\x04\0\0\x01\x2b\x0e\0\0\0\0\0\0\
\x28\0\0\0\x01\0\0\x01\x34\x0e\0\0\0\0\0\0\x17\0\0\0\x01\0\0\0\0\x03\0\0\0\0\0\
\0\0\0\0\0\x17\0\0\0\x04\0\0\x02\0\0\0\x01\x42\x0e\0\0\0\0\0\0\x2b\0\0\0\0\0\0\
\0\0\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\x02\0\0\0\x01\x55\x0e\0\0\0\0\0\
\0\x2d\0\0\0\0\0\0\x01\x6a\x07\0\0\0\0\0\0\0\0\0\x0a\x59\x0f\0\0\x01\0\0\0\x18\
\0\0\0\x0a\0\0\0\0\0\0\0\x18\0\0\x0a\x5f\x0f\0\0\x05\0\0\x18\x10\0\0\0\x25\0\0\
\0\0\0\0\0\x01\0\0\0\x26\0\0\0\x04\0\0\0\x04\0\0\0\x2a\0\0\0\x08\0\0\0\x08\0\0\
\0\x2c\0\0\0\x10\0\0\x10\0\0\0\0\x2e\0\0\x10\x10\0\0\x08\0\0\0\x0a\x64\x0f\0\0\
\x01\0\0\0\x04\0\0\0\x29\0\0\0\0\0\0\0\x04\0\0\x0a\x6c\x0f\0\0\x02\0\0\0\0\0\0\
\0\x1c\0\0\0\0\0\0\0\0\0\0\0\x1e\0\0\0\0\0\0\0\0\0\x69\x6e\x74\0\x5f\x5f\x41\
\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x74\x79\x70\
\x65\0\x6d\x61\x70\x5f\x66\x6c\x61\x67\x73\0\x6d\x61\x78\x5f\x65\x6e\x74\x72\
\x69\x65\x73\0\x61\x72\x65\x6e\x61\0\x68\x74\x61\x62\x5f\x74\0\x68\x74\x61\x62\
\0\x62\x75\x63\x6b\x65\x74\x73\0\x6e\x5f\x62\x75\x63\x6b\x65\x74\x73\0\x68\x74\
\x61\x62\x5f\x62\x75\x63\x6b\x65\x74\x5f\x74\0\x6b\x65\x79\0\x68\x74\x61\x62\
\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\0\x61\x72\x67\x3a\x61\x72\x65\
\x6e\x61\0\x76\x61\x6c\x75\x65\0\x68\x74\x61\x62\x5f\x75\x70\x64\x61\x74\x65\
\x5f\x65\x6c\x65\x6d\0\x5f\x5f\x75\x33\x32\0\x75\x6e\x73\x69\x67\x6e\x65\x64\
\x20\x69\x6e\x74\0\x5f\x5f\x75\x36\x34\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\
\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\0\x62\x70\x66\x5f\x61\x72\x65\x6e\x61\x5f\
\x61\x6c\x6c\x6f\x63\x5f\x70\x61\x67\x65\x73\0\x62\x70\x66\x5f\x61\x72\x65\x6e\
\x61\x5f\x66\x72\x65\x65\x5f\x70\x61\x67\x65\x73\0\x68\x74\x61\x62\x5f\x69\x6e\
\x69\x74\0\x63\x74\x78\0\x61\x72\x65\x6e\x61\x5f\x68\x74\x61\x62\x5f\x6c\x6c\
\x76\x6d\0\x62\x6f\x6f\x6c\0\x5f\x42\x6f\x6f\x6c\0\x73\x6b\x69\x70\0\x7a\x65\
\x72\x6f\0\x63\x68\x61\x72\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x68\x74\x61\x62\
\x5f\x66\x6f\x72\x5f\x75\x73\x65\x72\0\x70\x61\x67\x65\x5f\x66\x72\x61\x67\x5f\
\x63\x75\x72\x5f\x70\x61\x67\x65\0\x70\x61\x67\x65\x5f\x66\x72\x61\x67\x5f\x63\
\x75\x72\x5f\x6f\x66\x66\x73\x65\x74\0\x68\x74\x61\x62\x5f\x62\x75\x63\x6b\x65\
\x74\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\
\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x35\
\x32\x37\x2e\x65\x6c\x39\x2f\x6c\x69\x6e\x75\x78\x2d\x35\x2e\x31\x34\x2e\x30\
\x2d\x35\x32\x37\x2e\x65\x6c\x39\x2e\x73\x33\x39\x30\x78\x2f\x74\x6f\x6f\x6c\
\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\
\x2f\x62\x70\x66\x2f\x62\x70\x66\x5f\x61\x72\x65\x6e\x61\x5f\x68\x74\x61\x62\
\x2e\x68\0\x09\x63\x61\x73\x74\x5f\x6b\x65\x72\x6e\x28\x68\x74\x61\x62\x29\x3b\
\0\x09\x68\x74\x61\x62\x5f\x62\x75\x63\x6b\x65\x74\x5f\x74\x20\x2a\x62\x20\x3d\
\x20\x68\x74\x61\x62\x2d\x3e\x62\x75\x63\x6b\x65\x74\x73\x3b\0\x09\x63\x61\x73\
\x74\x5f\x6b\x65\x72\x6e\x28\x62\x29\x3b\0\x09\x72\x65\x74\x75\x72\x6e\x20\x26\
\x62\x5b\x68\x61\x73\x68\x20\x26\x20\x28\x68\x74\x61\x62\x2d\x3e\x6e\x5f\x62\
\x75\x63\x6b\x65\x74\x73\x20\x2d\x20\x31\x29\x5d\x3b\0\x09\x6c\x69\x73\x74\x5f\
\x66\x6f\x72\x5f\x65\x61\x63\x68\x5f\x65\x6e\x74\x72\x79\x28\x6c\x2c\x20\x68\
\x65\x61\x64\x2c\x20\x68\x61\x73\x68\x5f\x6e\x6f\x64\x65\x29\0\x09\x09\x69\x66\
\x20\x28\x6c\x2d\x3e\x68\x61\x73\x68\x20\x3d\x3d\x20\x68\x61\x73\x68\x20\x26\
\x26\x20\x6c\x2d\x3e\x6b\x65\x79\x20\x3d\x3d\x20\x6b\x65\x79\x29\0\x09\x09\x72\
\x65\x74\x75\x72\x6e\x20\x6c\x5f\x6f\x6c\x64\x2d\x3e\x76\x61\x6c\x75\x65\x3b\0\
\x7d\0\x5f\x5f\x77\x65\x61\x6b\x20\x69\x6e\x74\x20\x68\x74\x61\x62\x5f\x75\x70\
\x64\x61\x74\x65\x5f\x65\x6c\x65\x6d\x28\x68\x74\x61\x62\x5f\x74\x20\x2a\x68\
\x74\x61\x62\x20\x5f\x5f\x61\x72\x67\x5f\x61\x72\x65\x6e\x61\x2c\x20\x69\x6e\
\x74\x20\x6b\x65\x79\x2c\x20\x69\x6e\x74\x20\x76\x61\x6c\x75\x65\x29\0\x2f\x62\
\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\
\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x35\x32\x37\x2e\
\x65\x6c\x39\x2f\x6c\x69\x6e\x75\x78\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x35\x32\
\x37\x2e\x65\x6c\x39\x2e\x73\x33\x39\x30\x78\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\
\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\
\x66\x2f\x62\x70\x66\x5f\x61\x72\x65\x6e\x61\x5f\x61\x6c\x6c\x6f\x63\x2e\x68\0\
\x09\x5f\x5f\x75\x33\x32\x20\x63\x70\x75\x20\x3d\x20\x62\x70\x66\x5f\x67\x65\
\x74\x5f\x73\x6d\x70\x5f\x70\x72\x6f\x63\x65\x73\x73\x6f\x72\x5f\x69\x64\x28\
\x29\x3b\0\x09\x76\x6f\x69\x64\x20\x5f\x5f\x61\x72\x65\x6e\x61\x20\x2a\x70\x61\
\x67\x65\x20\x3d\x20\x70\x61\x67\x65\x5f\x66\x72\x61\x67\x5f\x63\x75\x72\x5f\
\x70\x61\x67\x65\x5b\x63\x70\x75\x5d\x3b\0\x09\x69\x6e\x74\x20\x5f\x5f\x61\x72\
\x65\x6e\x61\x20\x2a\x63\x75\x72\x5f\x6f\x66\x66\x73\x65\x74\x20\x3d\x20\x26\
\x70\x61\x67\x65\x5f\x66\x72\x61\x67\x5f\x63\x75\x72\x5f\x6f\x66\x66\x73\x65\
\x74\x5b\x63\x70\x75\x5d\x3b\0\x09\x69\x66\x20\x28\x21\x70\x61\x67\x65\x29\x20\
\x7b\0\x09\x09\x70\x61\x67\x65\x20\x3d\x20\x62\x70\x66\x5f\x61\x72\x65\x6e\x61\
\x5f\x61\x6c\x6c\x6f\x63\x5f\x70\x61\x67\x65\x73\x28\x26\x61\x72\x65\x6e\x61\
\x2c\x20\x4e\x55\x4c\x4c\x2c\x20\x31\x2c\x20\x4e\x55\x4d\x41\x5f\x4e\x4f\x5f\
\x4e\x4f\x44\x45\x2c\x20\x30\x29\x3b\0\x09\x09\x69\x66\x20\x28\x21\x70\x61\x67\
\x65\x29\0\x09\x09\x63\x61\x73\x74\x5f\x6b\x65\x72\x6e\x28\x70\x61\x67\x65\x29\
\x3b\0\x09\x09\x70\x61\x67\x65\x5f\x66\x72\x61\x67\x5f\x63\x75\x72\x5f\x70\x61\
\x67\x65\x5b\x63\x70\x75\x5d\x20\x3d\x20\x70\x61\x67\x65\x3b\0\x09\x09\x2a\x6f\
\x62\x6a\x5f\x63\x6e\x74\x20\x3d\x20\x30\x3b\0\x09\x6f\x66\x66\x73\x65\x74\x20\
\x3d\x20\x2a\x63\x75\x72\x5f\x6f\x66\x66\x73\x65\x74\x20\x2d\x20\x73\x69\x7a\
\x65\x3b\0\x09\x69\x66\x20\x28\x6f\x66\x66\x73\x65\x74\x20\x3c\x20\x30\x29\0\
\x09\x28\x2a\x6f\x62\x6a\x5f\x63\x6e\x74\x29\x2b\x2b\x3b\0\x09\x2a\x63\x75\x72\
\x5f\x6f\x66\x66\x73\x65\x74\x20\x3d\x20\x6f\x66\x66\x73\x65\x74\x3b\0\x09\x72\
\x65\x74\x75\x72\x6e\x20\x70\x61\x67\x65\x20\x2b\x20\x6f\x66\x66\x73\x65\x74\
\x3b\0\x09\x6c\x5f\x6e\x65\x77\x2d\x3e\x76\x61\x6c\x75\x65\x20\x3d\x20\x76\x61\
\x6c\x75\x65\x3b\0\x09\x6c\x5f\x6e\x65\x77\x2d\x3e\x68\x61\x73\x68\x20\x3d\x20\
\x68\x74\x61\x62\x5f\x68\x61\x73\x68\x28\x6b\x65\x79\x29\x3b\0\x09\x6c\x5f\x6e\
\x65\x77\x2d\x3e\x6b\x65\x79\x20\x3d\x20\x6b\x65\x79\x3b\0\x2f\x62\x75\x69\x6c\
\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\
\x72\x6e\x65\x6c\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x35\x32\x37\x2e\x65\x6c\x39\
\x2f\x6c\x69\x6e\x75\x78\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x35\x32\x37\x2e\x65\
\x6c\x39\x2e\x73\x33\x39\x30\x78\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\
\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x62\
\x70\x66\x5f\x61\x72\x65\x6e\x61\x5f\x6c\x69\x73\x74\x2e\x68\0\x09\x61\x72\x65\
\x6e\x61\x5f\x6c\x69\x73\x74\x5f\x6e\x6f\x64\x65\x5f\x74\x20\x2a\x66\x69\x72\
\x73\x74\x20\x3d\x20\x68\x2d\x3e\x66\x69\x72\x73\x74\x2c\x20\x2a\x20\x5f\x5f\
\x61\x72\x65\x6e\x61\x20\x2a\x74\x6d\x70\x3b\0\x09\x63\x61\x73\x74\x5f\x75\x73\
\x65\x72\x28\x66\x69\x72\x73\x74\x29\x3b\0\x09\x6c\x69\x73\x74\x5f\x61\x64\x64\
\x5f\x68\x65\x61\x64\x28\x26\x6c\x5f\x6e\x65\x77\x2d\x3e\x68\x61\x73\x68\x5f\
\x6e\x6f\x64\x65\x2c\x20\x68\x65\x61\x64\x29\x3b\0\x09\x63\x61\x73\x74\x5f\x6b\
\x65\x72\x6e\x28\x6e\x29\x3b\0\x09\x57\x52\x49\x54\x45\x5f\x4f\x4e\x43\x45\x28\
\x6e\x2d\x3e\x6e\x65\x78\x74\x2c\x20\x66\x69\x72\x73\x74\x29\x3b\0\x09\x63\x61\
\x73\x74\x5f\x6b\x65\x72\x6e\x28\x66\x69\x72\x73\x74\x29\x3b\0\x09\x69\x66\x20\
\x28\x66\x69\x72\x73\x74\x29\x20\x7b\0\x09\x09\x63\x61\x73\x74\x5f\x75\x73\x65\
\x72\x28\x74\x6d\x70\x29\x3b\0\x09\x09\x57\x52\x49\x54\x45\x5f\x4f\x4e\x43\x45\
\x28\x66\x69\x72\x73\x74\x2d\x3e\x70\x70\x72\x65\x76\x2c\x20\x74\x6d\x70\x29\
\x3b\0\x09\x63\x61\x73\x74\x5f\x75\x73\x65\x72\x28\x6e\x29\x3b\0\x09\x57\x52\
\x49\x54\x45\x5f\x4f\x4e\x43\x45\x28\x68\x2d\x3e\x66\x69\x72\x73\x74\x2c\x20\
\x6e\x29\x3b\0\x09\x63\x61\x73\x74\x5f\x75\x73\x65\x72\x28\x74\x6d\x70\x29\x3b\
\0\x09\x57\x52\x49\x54\x45\x5f\x4f\x4e\x43\x45\x28\x6e\x2d\x3e\x70\x70\x72\x65\
\x76\x2c\x20\x74\x6d\x70\x29\x3b\0\x09\x69\x66\x20\x28\x6c\x5f\x6f\x6c\x64\x29\
\x20\x7b\0\x09\x61\x72\x65\x6e\x61\x5f\x6c\x69\x73\x74\x5f\x6e\x6f\x64\x65\x5f\
\x74\x20\x2a\x6e\x65\x78\x74\x20\x3d\x20\x6e\x2d\x3e\x6e\x65\x78\x74\x2c\x20\
\x2a\x74\x6d\x70\x3b\0\x09\x61\x72\x65\x6e\x61\x5f\x6c\x69\x73\x74\x5f\x6e\x6f\
\x64\x65\x5f\x74\x20\x2a\x20\x5f\x5f\x61\x72\x65\x6e\x61\x20\x2a\x70\x70\x72\
\x65\x76\x20\x3d\x20\x6e\x2d\x3e\x70\x70\x72\x65\x76\x3b\0\x09\x63\x61\x73\x74\
\x5f\x75\x73\x65\x72\x28\x6e\x65\x78\x74\x29\x3b\0\x09\x63\x61\x73\x74\x5f\x6b\
\x65\x72\x6e\x28\x70\x70\x72\x65\x76\x29\x3b\0\x09\x74\x6d\x70\x20\x3d\x20\x2a\
\x70\x70\x72\x65\x76\x3b\0\x09\x63\x61\x73\x74\x5f\x6b\x65\x72\x6e\x28\x74\x6d\
\x70\x29\x3b\0\x09\x57\x52\x49\x54\x45\x5f\x4f\x4e\x43\x45\x28\x74\x6d\x70\x2c\
\x20\x6e\x65\x78\x74\x29\x3b\0\x09\x69\x66\x20\x28\x6e\x65\x78\x74\x29\x20\x7b\
\0\x09\x09\x63\x61\x73\x74\x5f\x75\x73\x65\x72\x28\x70\x70\x72\x65\x76\x29\x3b\
\0\x09\x09\x63\x61\x73\x74\x5f\x6b\x65\x72\x6e\x28\x6e\x65\x78\x74\x29\x3b\0\
\x09\x09\x57\x52\x49\x54\x45\x5f\x4f\x4e\x43\x45\x28\x6e\x65\x78\x74\x2d\x3e\
\x70\x70\x72\x65\x76\x2c\x20\x70\x70\x72\x65\x76\x29\x3b\0\x09\x6e\x2d\x3e\x70\
\x70\x72\x65\x76\x20\x3d\x20\x4c\x49\x53\x54\x5f\x50\x4f\x49\x53\x4f\x4e\x32\
\x3b\0\x09\x6e\x2d\x3e\x6e\x65\x78\x74\x20\x3d\x20\x4c\x49\x53\x54\x5f\x50\x4f\
\x49\x53\x4f\x4e\x31\x3b\0\x09\x61\x64\x64\x72\x20\x3d\x20\x28\x76\x6f\x69\x64\
\x20\x5f\x5f\x61\x72\x65\x6e\x61\x20\x2a\x29\x28\x28\x28\x6c\x6f\x6e\x67\x29\
\x61\x64\x64\x72\x29\x20\x26\x20\x7e\x28\x50\x41\x47\x45\x5f\x53\x49\x5a\x45\
\x20\x2d\x20\x31\x29\x29\x3b\0\x09\x69\x66\x20\x28\x2d\x2d\x28\x2a\x6f\x62\x6a\
\x5f\x63\x6e\x74\x29\x20\x3d\x3d\x20\x30\x29\0\x09\x09\x62\x70\x66\x5f\x61\x72\
\x65\x6e\x61\x5f\x66\x72\x65\x65\x5f\x70\x61\x67\x65\x73\x28\x26\x61\x72\x65\
\x6e\x61\x2c\x20\x61\x64\x64\x72\x2c\x20\x31\x29\x3b\0\x76\x6f\x69\x64\x20\x68\
\x74\x61\x62\x5f\x69\x6e\x69\x74\x28\x68\x74\x61\x62\x5f\x74\x20\x2a\x68\x74\
\x61\x62\x29\0\x09\x76\x6f\x69\x64\x20\x5f\x5f\x61\x72\x65\x6e\x61\x20\x2a\x62\
\x75\x63\x6b\x65\x74\x73\x20\x3d\x20\x62\x70\x66\x5f\x61\x72\x65\x6e\x61\x5f\
\x61\x6c\x6c\x6f\x63\x5f\x70\x61\x67\x65\x73\x28\x26\x61\x72\x65\x6e\x61\x2c\
\x20\x4e\x55\x4c\x4c\x2c\x20\x32\x2c\x20\x4e\x55\x4d\x41\x5f\x4e\x4f\x5f\x4e\
\x4f\x44\x45\x2c\x20\x30\x29\x3b\0\x09\x63\x61\x73\x74\x5f\x75\x73\x65\x72\x28\
\x62\x75\x63\x6b\x65\x74\x73\x29\x3b\0\x09\x68\x74\x61\x62\x2d\x3e\x6e\x5f\x62\
\x75\x63\x6b\x65\x74\x73\x20\x3d\x20\x32\x20\x2a\x20\x50\x41\x47\x45\x5f\x53\
\x49\x5a\x45\x20\x2f\x20\x73\x69\x7a\x65\x6f\x66\x28\x73\x74\x72\x75\x63\x74\
\x20\x68\x74\x61\x62\x5f\x62\x75\x63\x6b\x65\x74\x29\x3b\0\x09\x68\x74\x61\x62\
\x2d\x3e\x62\x75\x63\x6b\x65\x74\x73\x20\x3d\x20\x62\x75\x63\x6b\x65\x74\x73\
\x3b\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\
\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x35\
\x32\x37\x2e\x65\x6c\x39\x2f\x6c\x69\x6e\x75\x78\x2d\x35\x2e\x31\x34\x2e\x30\
\x2d\x35\x32\x37\x2e\x65\x6c\x39\x2e\x73\x33\x39\x30\x78\x2f\x74\x6f\x6f\x6c\
\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\
\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\x61\x72\x65\x6e\x61\x5f\x68\x74\
\x61\x62\x2e\x63\0\x09\x73\x6b\x69\x70\x20\x3d\x20\x74\x72\x75\x65\x3b\0\x09\
\x72\x65\x74\x75\x72\x6e\x20\x30\x3b\0\x2e\x6d\x61\x70\x73\0\x2e\x62\x73\x73\0\
\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x6b\x73\x79\x6d\x73\0\x2e\x74\x65\x78\x74\0\
\x73\x79\x73\x63\x61\x6c\x6c\0\0\0\0\0\0\0\0\xeb\x9f\x01\0\0\0\0\x20\0\0\0\0\0\
\0\0\x34\0\0\0\x34\0\0\x06\x54\0\0\x06\x88\0\0\0\0\0\0\0\x08\0\0\x0a\x73\0\0\0\
\x03\0\0\0\0\0\0\0\x11\0\0\0\xf0\0\0\0\x14\0\0\x05\0\0\0\0\x20\0\0\x0a\x79\0\0\
\0\x01\0\0\0\0\0\0\0\x22\0\0\0\x10\0\0\x0a\x73\0\0\0\x62\0\0\0\0\0\0\x01\x76\0\
\0\x01\xea\0\0\xf4\x02\0\0\0\x08\0\0\x01\x76\0\0\x01\xfc\0\0\x54\x1b\0\0\0\x10\
\0\0\x01\x76\0\0\x02\x1f\0\0\x5c\x02\0\0\0\x18\0\0\x01\x76\0\0\x02\x2e\0\0\x60\
\x1a\0\0\0\x20\0\0\x01\x76\0\0\x02\x2e\0\0\x60\x24\0\0\0\x28\0\0\x01\x76\0\0\
\x02\x2e\0\0\x60\x11\0\0\0\x30\0\0\x01\x76\0\0\x02\x2e\0\0\x60\x0a\0\0\0\x58\0\
\0\x01\x76\0\0\x02\x58\0\0\xb0\x02\0\0\0\x68\0\0\x01\x76\0\0\x02\x58\0\0\xb0\
\x02\0\0\0\x78\0\0\x01\x76\0\0\x02\x58\0\0\xb0\x02\0\0\0\x80\0\0\x01\x76\0\0\
\x02\x58\0\0\xb0\x02\0\0\0\x90\0\0\x01\x76\0\0\x02\x58\0\0\xb0\x02\0\0\0\x98\0\
\0\x01\x76\0\0\x02\x81\0\0\xb4\x0a\0\0\0\xa0\0\0\x01\x76\0\0\x02\x81\0\0\xb4\
\x0f\0\0\0\xb8\0\0\x01\x76\0\0\x02\x81\0\0\xb4\x17\0\0\0\xc0\0\0\x01\x76\0\0\
\x02\x81\0\0\xb4\x1d\0\0\0\xc8\0\0\x01\x76\0\0\x02\x81\0\0\xb4\x07\0\0\0\xd0\0\
\0\x01\x76\0\0\x02\x58\0\0\xb0\x02\0\0\0\xe0\0\0\x01\x76\0\0\x02\xa9\0\x01\x04\
\x11\0\0\0\xe8\0\0\x01\x76\0\0\x02\xc0\0\x01\x0c\x01\0\0\0\xf0\0\0\x01\x76\0\0\
\x02\xc2\0\x01\x14\0\0\0\x01\0\0\0\x01\x76\0\0\x01\xea\0\x01\x28\x02\0\0\x01\
\x08\0\0\x01\x76\0\0\x01\xfc\0\0\x54\x1b\0\0\x01\x10\0\0\x01\x76\0\0\x02\x1f\0\
\0\x5c\x02\0\0\x01\x18\0\0\x01\x76\0\0\x02\x2e\0\0\x60\x1a\0\0\x01\x20\0\0\x01\
\x76\0\0\x02\x2e\0\0\x60\x24\0\0\x01\x28\0\0\x01\x76\0\0\x02\x2e\0\0\x60\x11\0\
\0\x01\x30\0\0\x01\x76\0\0\x02\x2e\0\0\x60\x0a\0\0\x01\x58\0\0\x01\x76\0\0\x02\
\x58\0\0\xb0\x02\0\0\x01\x68\0\0\x01\x76\0\0\x02\x58\0\0\xb0\x02\0\0\x01\x78\0\
\0\x01\x76\0\0\x02\x58\0\0\xb0\x02\0\0\x01\x80\0\0\x01\x76\0\0\x02\x58\0\0\xb0\
\x02\0\0\x01\x90\0\0\x01\x76\0\0\x02\x58\0\0\xb0\x02\0\0\x01\x98\0\0\x01\x76\0\
\0\x02\x81\0\0\xb4\x0a\0\0\x01\xa0\0\0\x01\x76\0\0\x02\x81\0\0\xb4\x0f\0\0\x01\
\xb8\0\0\x01\x76\0\0\x02\x81\0\0\xb4\x17\0\0\x01\xc0\0\0\x01\x76\0\0\x02\x81\0\
\0\xb4\x1d\0\0\x01\xc8\0\0\x01\x76\0\0\x02\x81\0\0\xb4\x07\0\0\x01\xd0\0\0\x01\
\x76\0\0\x02\x58\0\0\xb0\x02\0\0\x01\xf8\0\0\x03\x0c\0\0\x03\x81\0\0\x5c\x0e\0\
\0\x02\0\0\0\x03\x0c\0\0\x03\xaa\0\0\x60\x17\0\0\x02\x10\0\0\x03\x0c\0\0\x03\
\xd9\0\0\x64\x1d\0\0\x02\x38\0\0\x03\x0c\0\0\x03\xaa\0\0\x60\x17\0\0\x02\x60\0\
\0\x03\x0c\0\0\x04\x10\0\0\x7c\x06\0\0\x02\x68\0\0\x03\x0c\0\0\x04\x1e\0\0\x84\
\x0a\0\0\x02\xc0\0\0\x03\x0c\0\0\x04\x60\0\0\x88\x07\0\0\x02\xc8\0\0\x03\x0c\0\
\0\x04\x6d\0\0\x90\x03\0\0\x02\xd0\0\0\x03\x0c\0\0\x04\x80\0\0\x94\x1b\0\0\x02\
\xd8\0\0\x03\x0c\0\0\x04\xa2\0\0\xa0\x0c\0\0\x03\0\0\0\x03\x0c\0\0\x04\x6d\0\0\
\xa8\x03\0\0\x03\x08\0\0\x03\x0c\0\0\x04\xb2\0\0\xb8\x0b\0\0\x03\x10\0\0\x03\
\x0c\0\0\x04\xb2\0\0\xb8\x17\0\0\x03\x38\0\0\x03\x0c\0\0\x04\xd0\0\0\xbc\x06\0\
\0\x03\x40\0\0\x03\x0c\0\0\x04\xe1\0\0\xc8\x0c\0\0\x03\x60\0\0\x03\x0c\0\0\x04\
\xf0\0\0\xcc\x0e\0\0\x03\x78\0\0\x03\x0c\0\0\x05\x07\0\0\xd0\x0e\0\0\x03\x80\0\
\0\x01\x76\0\0\x05\x1e\0\x01\x4c\x0f\0\0\x03\x90\0\0\x01\x76\0\0\x05\x35\0\x01\
\x48\x0e\0\0\x03\x98\0\0\x01\x76\0\0\x05\x54\0\x01\x44\x0d\0\0\x03\xa0\0\0\x05\
\x67\0\0\x05\xdb\0\0\xb4\x20\0\0\x03\xa8\0\0\x05\x67\0\0\x06\x11\0\0\xbc\x02\0\
\0\x03\xb0\0\0\x01\x76\0\0\x06\x24\0\x01\x54\x18\0\0\x03\xb8\0\0\x05\x67\0\0\
\x06\x4d\0\0\xc0\x02\0\0\x03\xc0\0\0\x05\x67\0\0\x06\x5c\0\0\xc4\x02\0\0\x03\
\xc8\0\0\x05\x67\0\0\x06\x79\0\0\xc8\x02\0\0\x03\xd0\0\0\x05\x67\0\0\x06\x8c\0\
\0\xcc\x06\0\0\x03\xd8\0\0\x05\x67\0\0\x06\x9a\0\0\xd4\x03\0\0\x03\xe8\0\0\x05\
\x67\0\0\x06\xac\0\0\xd8\x03\0\0\x03\xf0\0\0\x05\x67\0\0\x06\xcd\0\0\xe0\x02\0\
\0\x03\xf8\0\0\x05\x67\0\0\x06\xdc\0\0\xe4\x02\0\0\x04\0\0\0\x05\x67\0\0\x06\
\xf6\0\0\xf0\x02\0\0\x04\x08\0\0\x05\x67\0\0\x06\x4d\0\0\xf4\x02\0\0\x04\x10\0\
\0\x05\x67\0\0\x07\x07\0\0\xf8\x02\0\0\x04\x20\0\0\x01\x76\0\0\x07\x23\0\x01\
\x58\x06\0\0\x04\x28\0\0\x05\x67\0\0\x07\x31\0\x01\x0c\x1f\0\0\x04\x30\0\0\x05\
\x67\0\0\x07\x5b\0\x01\x10\x2a\0\0\x04\x38\0\0\x05\x67\0\0\x07\x8b\0\x01\x18\
\x02\0\0\x04\x40\0\0\x05\x67\0\0\x07\x9d\0\x01\x1c\x02\0\0\x04\x48\0\0\x05\x67\
\0\0\x07\xb0\0\x01\x20\x08\0\0\x04\x50\0\0\x05\x67\0\0\x07\xbf\0\x01\x24\x02\0\
\0\x04\x58\0\0\x05\x67\0\0\x07\xd0\0\x01\x28\x02\0\0\x04\x60\0\0\x05\x67\0\0\
\x07\xe8\0\x01\x2c\x06\0\0\x04\x68\0\0\x05\x67\0\0\x07\xf5\0\x01\x30\x03\0\0\
\x04\x70\0\0\x05\x67\0\0\x08\x09\0\x01\x34\x03\0\0\x04\x78\0\0\x05\x67\0\0\x08\
\x1c\0\x01\x38\x03\0\0\x04\x88\0\0\x05\x67\0\0\x08\x3e\0\x01\x6c\x0b\0\0\x04\
\x98\0\0\x05\x67\0\0\x08\x58\0\x01\x68\x0a\0\0\x04\xa0\0\0\x03\x0c\0\0\x08\x71\
\0\0\xec\x27\0\0\x04\xa8\0\0\x03\x0c\0\0\x08\xac\0\0\xf4\x06\0\0\x04\xc0\0\0\
\x03\x0c\0\0\x08\xac\0\0\xf4\x06\0\0\x04\xc8\0\0\x03\x0c\0\0\x08\xc4\0\0\xf8\
\x03\0\0\x04\xf0\0\0\x01\x76\0\0\x02\xc0\0\x01\x6c\x01\0\0\x05\0\0\0\x01\x76\0\
\0\x08\xed\0\x01\x74\0\0\0\x05\x08\0\0\x01\x76\0\0\x09\x0a\0\x01\x7c\x1a\0\0\
\x05\x48\0\0\x01\x76\0\0\x09\x5c\0\x01\x84\x02\0\0\x05\x58\0\0\x01\x76\0\0\x09\
\x71\0\x01\x8c\x12\0\0\x05\x60\0\0\x01\x76\0\0\x09\xb0\0\x01\x88\x10\0\0\x05\
\x68\0\0\x01\x76\0\0\x02\xc0\0\x01\x90\x01\0\0\x0a\x79\0\0\0\x02\0\0\0\0\0\0\
\x09\xca\0\0\x0a\x40\0\0\xac\x07\0\0\0\x20\0\0\x09\xca\0\0\x0a\x4e\0\0\xb4\x02\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\0\
\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\x01\x8e\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x01\xd0\0\0\0\0\0\0\x03\x30\0\0\0\x01\0\0\0\0\0\0\0\0\0\
\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x05\0\0\0\0\0\0\0\x05\x70\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\
\0\0\0\0\0\0\0\0\0\x17\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x0a\x70\0\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\
\0\0\x1f\0\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\xa0\0\0\0\
\0\0\0\0\x18\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x25\0\0\0\
\x08\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\xb8\0\0\0\0\0\0\x18\x10\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x2a\0\0\0\x01\0\0\0\0\
\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\xb8\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x01\x6a\0\0\0\x09\0\0\0\0\0\0\0\x40\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\xc0\0\0\0\0\0\0\0\x80\0\0\0\x02\0\0\0\x03\0\0\0\
\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x01\x74\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x0b\x40\0\0\0\0\0\0\0\x10\0\0\0\x02\0\0\0\x04\0\0\0\0\0\0\
\0\x08\0\0\0\0\0\0\0\x10\0\0\x01\x80\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x0b\x50\0\0\0\0\0\0\x0e\xa1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\
\0\0\0\0\0\0\0\0\x01\x85\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x19\xf8\0\0\0\0\0\0\x06\xa8\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0";

	*sz = sizeof(data) - 1;
	return (const void *)data;
}

#ifdef __cplusplus
struct arena_htab *arena_htab::open(const struct bpf_object_open_opts *opts) { return arena_htab__open_opts(opts); }
struct arena_htab *arena_htab::open_and_load() { return arena_htab__open_and_load(); }
int arena_htab::load(struct arena_htab *skel) { return arena_htab__load(skel); }
int arena_htab::attach(struct arena_htab *skel) { return arena_htab__attach(skel); }
void arena_htab::detach(struct arena_htab *skel) { arena_htab__detach(skel); }
void arena_htab::destroy(struct arena_htab *skel) { arena_htab__destroy(skel); }
const void *arena_htab::elf_bytes(size_t *sz) { return arena_htab__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
arena_htab__assert(struct arena_htab *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
	_Static_assert(sizeof(s->bss->skip) == 1, "unexpected size of 'skip'");
	_Static_assert(sizeof(s->bss->zero) == 4, "unexpected size of 'zero'");
	_Static_assert(sizeof(s->bss->htab_for_user) == 8, "unexpected size of 'htab_for_user'");
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __ARENA_HTAB_SKEL_H__ */
